<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\Support\Arr;
use SimpleXMLIterator;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;

class ObjectParser implements ItemParser
{

    public const TAG = 'object';

    /**
     * Contains a group of parsers
     * @var ItemParser[]
     */
    private $parsers;

    /**
     * ObjectParser constructor.
     *
     * @since 0.1
     *
     * @param ItemParser[]
     */
    public function __construct(array $parsers)
    {
        $this->parsers = $parsers;
    }

    private function getType(SimpleXMLIterator $el)
    {
        return Arr::get(Arr::get((array)$el->attributes(), '@attributes', []), 'type', '');
    }

    private function getParser(SimpleXMLIterator $el)
    {
        return Arr::get($this->parsers, $this->getType($el), null);
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $parser = $this->getParser($element);

        if ($parser instanceof ItemParser) {
            return $parser->parse($element);
        }

        return [];
    }
}
